@@ -1,7 +1,7 @@
 package Complete::Util;
 
 our $DATE = '2016-10-14'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $VERSION = '0.52'; # VERSION
 
 use 5.010001;
 use strict;
@@ -114,6 +114,7 @@ sub __min(@) {
 }
 
 our $code_editdist;
+our $editdist_flex;
 
 # straight copy of Wikipedia's "Levenshtein Distance"
 sub __editdist {
@@ -313,24 +314,27 @@ sub complete_array_elem {
     # fuzzy matching
     if ($fuzzy && !@words) {
         $log->tracef("[computil] Trying fuzzy matching ...") if $COMPLETE_UTIL_TRACE;
-        my $flex;
         $code_editdist //= do {
             my $env = $ENV{COMPLETE_UTIL_LEVENSHTEIN} // '';
             if ($env eq 'xs') {
                 require Text::Levenshtein::XS;
+                $editdist_flex = 0;
                 \&Text::Levenshtein::XS::distance;
             } elsif ($env eq 'flexible') {
                 require Text::Levenshtein::Flexible;
-                $flex = 1;
+                $editdist_flex = 1;
                 \&Text::Levenshtein::Flexible::levenshtein_l;
             } elsif ($env eq 'pp') {
+                $editdist_flex = 0;
                 \&__editdist;
             } elsif (eval { require Text::Levenshtein::Flexible; 1 }) {
-                $flex = 1;
+                $editdist_flex = 1;
                 \&Text::Levenshtein::Flexible::levenshtein_l;
             } elsif (eval { require Text::Levenshtein::XS; 1 }) {
+                $editdist_flex = 0;
                 \&Text::Levenshtein::XS::distance;
             } else {
+                $editdist_flex = 0;
                 \&__editdist;
             }
         };
@@ -357,7 +361,7 @@ sub complete_array_elem {
                 );
                 my $d;
                 unless (defined $editdists{$chopped}) {
-                    if ($flex) {
+                    if ($editdist_flex) {
                         $d = $code_editdist->($wordn, $chopped, $maxd);
                         next ELEM unless defined $d;
                     } else {
@@ -606,7 +610,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.51 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-14.
+This document describes version 0.52 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-14.
 
 =head1 DESCRIPTION
 
@@ -798,6 +802,33 @@ Metadata (extra keys) for the hash.
 
 Return value:  (hash)
 
+=head1 FAQ
+
+=head2 Why is fuzzy matching slow?
+
+Example:
+
+ use Benchmark qw(timethis);
+ use Complete::Util qw(complete_array_elem);
+
+ # turn off the other non-exact matching methods
+ $Complete::Common::OPT_CI = 0;
+ $Complete::Common::OPT_WORD_MODE = 0;
+ $Complete::Common::OPT_CHAR_MODE = 0;
+
+ my @ary = ("aaa".."zzy"); # 17575 elems
+ timethis(20, sub { complete_array_elem(array=>\@ary, word=>"zzz") });
+
+results in:
+
+ timethis 20:  7 wallclock secs ( 6.82 usr +  0.00 sys =  6.82 CPU) @  2.93/s (n=20)
+
+Answer: you will need to install either L<Text::Levenshtein::Flexible> or
+L<Text::Levenshtein::XS> to speed up fuzzy matching (these modules are declared
+as optional prereqs). After Text::Levenshtein::Flexible is installed:
+
+ timethis 20:  1 wallclock secs ( 1.04 usr +  0.00 sys =  1.04 CPU) @ 19.23/s (n=20)
+
 =head1 ENVIRONMENT
 
 =head2 COMPLETE_UTIL_TRACE => bool
